@@ -129,10 +129,9 @@ char *hexcode(void *data, int datalen) {
 		data_num[i]=='&' || data_num[i]=='=' || \
 		data_num[i]==':' || data_num[i]=='@' || \
 		data_num[i]=='?' || data_num[i]=='%' || \
-		data_num[i]=='+') {
+		data_num[i]=='+' || data_num[i]=='#') {
 #else
 		/* If the charectar is not alphanumeric or and not [+./-], convert it to hex. */
-		/* This is no longer used in favor of a more leanient algorithm. */
 		if (!isalnum(data_num[i]) && data_num[i]!='/' && data_num[i]!='.' && data_num[i]!='~' && data_num[i]!='+') {
 #endif
 			ret[destpos++]='#';
