@@ -21,7 +21,8 @@
 #ifndef _DACT_NET_H 
 #define _DACT_NET_H
 
-int createlisten(int port, int localonly);
+int createlisten(int port, int localonly, int type);
 void closeconnection(int sockfd);
+int createconnection(char *host, int port, int type);
 int createconnection_tcp(char *host, int port);
 #endif
